==> homelawnsecurity-0.0.5.1-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/ConeheadZombieRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.custom.zombie.BasicZombieEntity;
import net.db64.homelawnsecurity.entity.custom.zombie.ConeheadZombieEntity;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class ConeheadZombieRenderer extends class_927<ConeheadZombieEntity, ConeheadZombieRenderState, ConeheadZombieModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/conehead_zombie.png");

	public ConeheadZombieRenderer(class_5617.class_5618 context) {
		super(context, new ConeheadZombieModel(context.method_32167(ModModelLayers.Zombie.CONEHEAD_ZOMBIE)), 0.5f);
	}

	@Override
	public class_2960 getTexture(ConeheadZombieRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(ConeheadZombieRenderState state, class_4587 matrixStack, class_4597 vertexConsumerProvider, int light) {
		super.method_4054(state, matrixStack, vertexConsumerProvider, light);
	}

	@Override
	public ConeheadZombieRenderState method_55269() {
		return new ConeheadZombieRenderState();
	}

	@Override
	public void updateRenderState(ConeheadZombieEntity entity, ConeheadZombieRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.hasLostHeadwear = entity.hasTriggeredDegradationStage("headwear");
		state.hasLostArm = entity.hasTriggeredDegradationStage("arm");
		state.hasLostHead = entity.hasTriggeredDegradationStage("head");
		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.attackAnimationState.method_61401(entity.attackAnimationState);
	}
}

==> homelawnsecurity-0.0.5.2-sources.jar: net/db64/homelawnsecurity/entity/client/zombie/ConeheadZombieRenderer.java <==
package net.db64.homelawnsecurity.entity.client.zombie;

import net.db64.homelawnsecurity.HomeLawnSecurity;
import net.db64.homelawnsecurity.entity.client.ModModelLayers;
import net.db64.homelawnsecurity.entity.custom.zombie.BasicZombieEntity;
import net.db64.homelawnsecurity.entity.custom.zombie.ConeheadZombieEntity;
import net.minecraft.class_11659;
import net.minecraft.class_12075;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_5617;
import net.minecraft.class_927;

public class ConeheadZombieRenderer extends class_927<ConeheadZombieEntity, ConeheadZombieRenderState, ConeheadZombieModel> {
	private static final class_2960 TEXTURE = class_2960.method_60655(HomeLawnSecurity.MOD_ID, "textures/entity/zombie/conehead_zombie.png");

	public ConeheadZombieRenderer(class_5617.class_5618 context) {
		super(context, new ConeheadZombieModel(context.method_32167(ModModelLayers.Zombie.CONEHEAD_ZOMBIE)), 0.5f);
	}

	@Override
	public class_2960 getTexture(ConeheadZombieRenderState state) {
		return TEXTURE;
	}

	@Override
	public void render(
		ConeheadZombieRenderState state,
		class_4587 matrixStack,
		class_11659 orderedRenderCommandQueue,
		class_12075 cameraRenderState
	) {
		super.method_4054(state, matrixStack, orderedRenderCommandQueue, cameraRenderState);
	}

	@Override
	public ConeheadZombieRenderState method_55269() {
		return new ConeheadZombieRenderState();
	}

	@Override
	public void updateRenderState(ConeheadZombieEntity entity, ConeheadZombieRenderState state, float f) {
		super.method_62355(entity, state, f);

		state.hasLostHeadwear = entity.hasTriggeredDegradationStage("headwear");
		state.hasLostArm = entity.hasTriggeredDegradationStage("arm");
		state.hasLostHead = entity.hasTriggeredDegradationStage("head");
		state.setupAnimationState.method_61401(entity.setupAnimationState);
		state.attackAnimationState.method_61401(entity.attackAnimationState);
	}
}
